==> browsergui-0.2.0.tar.gz: browsergui-0.2.0/test/test_dropdown.py <==
from browsergui import Dropdown, Text
from . import BrowserGUITestCase

def dropdown_xml(*options):
  return '<select>{}</select>'.format(''.join('<option value="{s}">{s}</option>'.format(s=s) for s in options))

class DropdownTest(BrowserGUITestCase):

  def test_construction(self):
    self.assertEqual([], list(Dropdown()))
    self.assertEqual(['a', 'b'], list(Dropdown(['a', 'b'])))

  def test_options_must_be_strings(self):
    with self.assertRaises(TypeError):
      Dropdown([()])

    d = Dropdown(['a'])
    with self.assertRaises(TypeError):
      d[0] = ()
    with self.assertRaises(TypeError):
      d.insert(0, ())

  def test_getitem(self):
    d = Dropdown(['a', 'b'])
    self.assertEqual(['a', 'b'], d[:])
    self.assertEqual('a', d[0])
    with self.assertRaises(IndexError):
      d[2]

  def test_delitem(self):
    d = Dropdown(['a', 'b'])

    del d[0]
    self.assertEqual('b', d[0])
    with self.assertRaises(IndexError):
      d[1]

    self.assertHTMLLike(dropdown_xml('b'), d, ignored_attrs=['id', 'oninput', 'selected'])

  def test_setitem(self):
    d = Dropdown(['a', 'b'])

    d[0] = 'c'
    self.assertEqual(d[0], 'c')
    self.assertEqual(2, len(d))

    self.assertHTMLLike(dropdown_xml('c', 'b'), d, ignored_attrs=['id', 'oninput', 'selected'])

  def test_insert(self):
    d = Dropdown()

    d.insert(0, 'b')
    d.insert(0, 'a')
    d.insert(99, 'd')
    d.insert(-1, 'c')
    self.assertEqual(['a', 'b', 'c', 'd'], list(d))
    self.assertHTMLLike(dropdown_xml('a', 'b', 'c', 'd'), d, ignored_attrs=['id', 'oninput', 'selected'])

  def test_tag(self):
    self.assertHTMLLike('<select oninput="notify_server({target_id: this.getAttribute(&quot;id&quot;), type_name: event.type, value: this.value})" />', Dropdown(), ignored_attrs=['id'])
    self.assertHTMLLike('<select><option value="a">a</option><option value="b">b</option></select>', Dropdown(['a', 'b']), ignored_attrs=['id', 'oninput', 'selected'])

  def test_validation(self):
    d = Dropdown(['a', 'b', 'c'])

    for good_object in ('a', 'b', 'c'):
      d.value = good_object

    for bad_object in (0, []):
      with self.assertRaises(TypeError):
        d.value = bad_object

    # Commented for now because testing whether the value is in the set of options is hard,
    # because of how all the __init__ methods get tangled up, with tag-modification
    # and value-setting and validation.
    #
    # for bad_object in ('not in it'):
    #   with self.assertRaises(ValueError):
    #     d.value = bad_object

==> browsergui-0.2.2.tar.gz: browsergui-0.2.2/test/test_dropdown.py <==
from browsergui import Dropdown, Text
from . import BrowserGUITestCase

def dropdown_xml(*options):
  return '<select>{}</select>'.format(''.join('<option value="{s}">{s}</option>'.format(s=s) for s in options))

class DropdownTest(BrowserGUITestCase):

  def test_construction(self):
    self.assertEqual([], list(Dropdown()))
    self.assertEqual(['a', 'b'], list(Dropdown(['a', 'b'])))

  def test_options_must_be_strings(self):
    with self.assertRaises(TypeError):
      Dropdown([()])

    d = Dropdown(['a'])
    with self.assertRaises(TypeError):
      d[0] = ()
    with self.assertRaises(TypeError):
      d.insert(0, ())

  def test_getitem(self):
    d = Dropdown(['a', 'b'])
    self.assertEqual(['a', 'b'], d[:])
    self.assertEqual('a', d[0])
    with self.assertRaises(IndexError):
      d[2]

  def test_delitem(self):
    d = Dropdown(['a', 'b'])

    del d[0]
    self.assertEqual('b', d[0])
    with self.assertRaises(IndexError):
      d[1]

    self.assertHTMLLike(dropdown_xml('b'), d, ignored_attrs=['id', 'oninput', 'selected'])

  def test_setitem(self):
    d = Dropdown(['a', 'b'])

    d[0] = 'c'
    self.assertEqual(d[0], 'c')
    self.assertEqual(2, len(d))

    self.assertHTMLLike(dropdown_xml('c', 'b'), d, ignored_attrs=['id', 'oninput', 'selected'])

  def test_insert(self):
    d = Dropdown()

    d.insert(0, 'b')
    d.insert(0, 'a')
    d.insert(99, 'd')
    d.insert(-1, 'c')
    self.assertEqual(['a', 'b', 'c', 'd'], list(d))
    self.assertHTMLLike(dropdown_xml('a', 'b', 'c', 'd'), d, ignored_attrs=['id', 'oninput', 'selected'])

  def test_tag(self):
    self.assertHTMLLike('<select oninput="notify_server({target_id: this.getAttribute(&quot;id&quot;), type_name: event.type, value: this.value})" />', Dropdown(), ignored_attrs=['id'])
    self.assertHTMLLike('<select><option value="a">a</option><option value="b">b</option></select>', Dropdown(['a', 'b']), ignored_attrs=['id', 'oninput', 'selected'])

  def test_validation(self):
    d = Dropdown(['a', 'b', 'c'])

    for good_object in ('a', 'b', 'c', u'a'):
      d.value = good_object

    for bad_object in (0, []):
      with self.assertRaises(TypeError):
        d.value = bad_object

    for bad_object in ('not in it'):
      with self.assertRaises(ValueError):
        d.value = bad_object
